#
# spec file for package peek
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           peek
Version:        1.0.3
Release:        lp152.3.7
Summary:        An animated GIF recorder
License:        GPL-3.0
Group:          Productivity/Graphics/Other
Url:            https://github.com/phw/peek
Source:         https://github.com/phw/peek/archive/v%{version}.tar.gz
BuildRequires:  cmake >= 2.8.8
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool >= 0.19
BuildRequires:  pkgconfig
BuildRequires:  txt2man
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.14
BuildRequires:  pkgconfig(keybinder-3.0)
BuildRequires:  pkgconfig(vapigen) >= 0.22
Requires:       ImageMagick
Requires:       ffmpeg
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%lang_package

%description
A simple tool that allows you to record short animated GIF images from your screen.
Currently, only X11 window system is supported.

%prep
%setup -q

%build
%cmake -DGSETTINGS_COMPILE=OFF
make %{?_smp_mflags}

%install
%cmake_install
%suse_update_desktop_file -r com.uploadedlobster.peek Utility DesktopUtility
%find_lang %{name}

%post
%glib2_gsettings_schema_post
%desktop_database_post
%icon_theme_cache_post

%postun
%glib2_gsettings_schema_postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc LICENSE
%{_bindir}/peek
%{_datadir}/glib-2.0/schemas/com.uploadedlobster.peek.gschema.xml
%{_datadir}/applications/com.uploadedlobster.peek.desktop
%dir %{_datadir}/icons/hicolor/512x512/apps/
%dir %{_datadir}/icons/hicolor/512x512/
%{_datadir}/icons/hicolor/*/apps/com.uploadedlobster.peek.png
%{_datadir}/dbus-1/services/com.uploadedlobster.peek.service
%{_mandir}/man1/peek.*
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/com.uploadedlobster.peek.appdata.xml

%files lang -f %{name}.lang
%defattr(-,root,root)

%changelog
* Sun Aug  6 2017 mailaender@opensuse.org
- ImageMagick and ffmpeg changed to runtime (not build) dependencies
- update to version 1.0.3
  * package: Fixed installing man page
- changes from version 1.0.2
  * feat: Finish saving file when closing window while rendering (#142)
  * feat: Highlight file when launching Dolphin file manager
  * recording: Use raw video for recording GIF with GNOME Shell recorder (this is identical to how FFmpeg recorder works) (#116)
  * fix: Failed to record MP4 when dimensions where not divisible by 2 (#141)
  * fix: Make sure recording starts after countdown is hidden (#146)
  * fix: Closing window while recording could leave temp files behind
  * fix: KDE Plasma and XFCE were showing an empty button in notification
  * fix: Place close button on the left on all desktops configured this way (#129)
  * fix: Cinammon showing notification with icon
  * i18n: Indonesian and Serbian translation
  * i18n: Updated translations for Basque, Esperanto, French, Portuguese (Brazil), Russian and Ukrainian
  * docs: Added man page (#136)
- changes from version 1.0.1
  * recording: Use H.264 baseline profile for MP4 for increased browser compatibility (#111)
  * recording: For WebM GNOME Shell recorder use same quality settings as with FFmpeg encoder
  * ui: Show only the most recent "file saved" notification to avoid spamming the desktop with notifications.
  * fix: Set temporary directory for ImageMagick
  * fix: Always launch with GDK_BACKEND=x11 for Wayland
  * fix: Detect if global menus are disabled in Unity when running as Flatpak / Snap package
  * i18n: Updated translations for Arabic, Czech, Russian and Spanish
  * i18n: New translations for Basque and Esperanto
- changes from version 1.0
  * recording: Support GNOME Shell screencast DBus service. Allows recording under GNOME Shell with XWayland (#33)
  * recording: Support WebM and MP4 as output format (#73)
  * recording: Added option to not record mouse cursor
  * recording: Default frame rate is now 10fps
  * ui: Recording can be started / stopped via configurable keyboard shortcut (#23)
  * ui: Add --start, --stop and --toggle command line parameters to control the recording
  * ui: Add --backend command line parameter to manually choose recording backend (gnome-shell, ffmpeg or avcodec for now)
  * ui: Hide button label on small window width. Allows for smaller recording area.
  * misc: Use org.freedesktop.FileManager1 DBus service for launching file manager.
  * fix: Fixed a possible race condition that could lead to empty or broken files (#1)
  * fix: Moving Peek partially outside the visible area does no longer break the recording. Instead the recording area is clipped to the visible part (#64)
  * fix: Starting recording in maximized window relocated the window on Ubuntu Unity (#74)
  * fix: When canceling the file chooser also stop the background processing of the image (#96)
  * i18n: Many updated translations, with Czech, Dutch, German, Lithuanian,
  * Polish and Swedish 100%% completed
  * package: Provide AppStream data
  * docs: Much improved README
- changes from version 0.9.1
  * i18n: Fixed Czech, Croatian, Korean, Dutch and Chinese (Simplified) not getting installed
- changes from version 0.9.0:
  * ui: Fix problem of app menu not available on certain desktop configurations (#6)
  * ui: Fix display of desktop notifications on Ubuntu Unity (#55)
  * ui: Close button is displayed left on Ubuntu Unity (#67)
  * ui: Workaround for gray borders under unity (#11)
  * ui: Smaller border around recording area
  * recording: Add resolution downsampling option (#32)
  * recording: Minimal frame rate is now 1fps
  * recording: Smaller temporary files by using libx264rgb instead of huffyuv (#2)
  * recording: Support for avconf, if ffmpeg is unavailable (#56)
  * i18n: Chinese (Simplified) translation
  * i18n: Croatian translation
  * i18n: Czech translation
  * i18n: Dutch translation
  * i18n: Italian translation
  * i18n: Korean translation
  * i18n: Norwegian Bokmål translation
  * i18n: Portuguese (Brazil) translation
  * i18n: Swedish translation
  * fix: Fix possible crash when loading schema from local folder
  * fix: Fix temp file deletion warning
  * docs: Update installation instructions
  * docs: Added FAQs
* Sat Jan 28 2017 jengelh@inai.de
- Trim irrelevant parts from description
* Fri Jan 27 2017 sebix+novell.com@sebix.at
- update to 0.8, upstream changes:
  * ui: Change button text while rendering (#24)
  * ui: Add a --version command line argument
  * ui: Show file choose directly after recording stops. This way
  * rendering and choosing the file take place in parallel (#30)
  * recording: Correctly scale recording area on HiDPI screens (#20)
  * i18n: Arabic translation
  * i18n: Catalan translation
  * i18n: French translation
  * i18n: Lithuanian translation
  * i18n: Polish translation
  * i18n: Portuguese (Portugal) translation
  * i18n: Russian translation
  * i18n: Spanish translation
  * i18n: Ukrainian translation
  * misc: Added generic name and sub category to desktop file
  * misc: Added uninstall target, so source installations can be uninstalled
  * with make uninstall (#28)
  * fix: Fix DBUS service file if installed to location other than /usr (#13)
  * fix: Locales not loaded if not installed to /usr due to missing locale path
* Sun Sep  4 2016 mailaender@opensuse.org
- initial packaging of version 0.7.2
